@@ -4,7 +4,7 @@ CREATE TABLE IF NOT EXISTS schema_version (
 
 DELETE FROM schema_version;
 
-INSERT INTO schema_version (version) VALUES (16);
+INSERT INTO schema_version (version) VALUES (17);
 
 CREATE TABLE IF NOT EXISTS directories (
   path TEXT NOT NULL,
@@ -67,8 +67,10 @@ CREATE TABLE IF NOT EXISTS songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -143,8 +145,10 @@ CREATE TABLE IF NOT EXISTS subsonic_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -219,8 +223,10 @@ CREATE TABLE IF NOT EXISTS tidal_artists_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -295,8 +301,10 @@ CREATE TABLE IF NOT EXISTS tidal_albums_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -371,8 +379,10 @@ CREATE TABLE IF NOT EXISTS tidal_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -447,8 +457,10 @@ CREATE TABLE IF NOT EXISTS qobuz_artists_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -523,8 +535,10 @@ CREATE TABLE IF NOT EXISTS qobuz_albums_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -599,8 +613,10 @@ CREATE TABLE IF NOT EXISTS qobuz_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
@@ -695,8 +711,10 @@ CREATE TABLE IF NOT EXISTS playlist_items (
   compilation_off INTEGER DEFAULT 0,
   compilation_effective INTEGER DEFAULT 0,
 
+  art_embedded INTEGER DEFAULT 0,
   art_automatic TEXT,
   art_manual TEXT,
+  art_unset INTEGER DEFAULT 0,
 
   effective_albumartist TEXT,
   effective_originalyear INTEGER,
