@@ -30,15 +30,13 @@
 #include <QAction>
 #include <QActionGroup>
 
-#include "engine/engine_fwd.h"
+#include "engine/enginebase.h"
 
 class QTimer;
 class QMouseEvent;
 class QWheelEvent;
 
-namespace Analyzer {
-class Base;
-}  // namespace Analyzer
+class AnalyzerBase;
 
 class AnalyzerContainer : public QWidget {
   Q_OBJECT
@@ -53,7 +51,7 @@ class AnalyzerContainer : public QWidget {
   static const char *kSettingsFramerate;
 
  signals:
-  void WheelEvent(int delta);
+  void WheelEvent(const int delta);
 
  protected:
   void mouseReleaseEvent(QMouseEvent*) override;
@@ -94,7 +92,7 @@ class AnalyzerContainer : public QWidget {
   QPoint last_click_pos_;
   bool ignore_next_click_;
 
-  Analyzer::Base *current_analyzer_;
+  AnalyzerBase *current_analyzer_;
   EngineBase *engine_;
 };
 
