@@ -58,8 +58,6 @@ SCollection::SCollection(Application *app, QObject *parent)
       watcher_(nullptr),
       watcher_thread_(nullptr),
       original_thread_(nullptr),
-      io_priority_(Utilities::IoPriority::IOPRIO_CLASS_IDLE),
-      thread_priority_(QThread::Priority::IdlePriority),
       save_playcounts_to_files_(false),
       save_ratings_to_files_(false) {
 
@@ -69,7 +67,7 @@ SCollection::SCollection(Application *app, QObject *parent)
   backend()->moveToThread(app->database()->thread());
   qLog(Debug) << backend_ << "moved to thread" << app->database()->thread();
 
-  backend_->Init(app->database(), app->task_manager(), Song::Source_Collection, kSongsTable, kFtsTable, kDirsTable, kSubdirsTable);
+  backend_->Init(app->database(), app->task_manager(), Song::Source::Collection, kSongsTable, kFtsTable, kDirsTable, kSubdirsTable);
 
   model_ = new CollectionModel(backend_, app_, this);
 
@@ -93,20 +91,16 @@ SCollection::~SCollection() {
 
 void SCollection::Init() {
 
-  watcher_ = new CollectionWatcher(Song::Source_Collection);
+  watcher_ = new CollectionWatcher(Song::Source::Collection);
   watcher_thread_ = new Thread(this);
 
-#ifndef Q_OS_WIN32
-  if (io_priority_ != Utilities::IoPriority::IOPRIO_CLASS_NONE) {
-    watcher_thread_->SetIoPriority(io_priority_);
-  }
-#endif
+  watcher_thread_->SetIoPriority(Utilities::IoPriority::IOPRIO_CLASS_IDLE);
 
   watcher_->moveToThread(watcher_thread_);
 
-  qLog(Debug) << watcher_ << "moved to thread" << watcher_thread_ << "with I/O priority" << io_priority_ << "and thread priority" << thread_priority_;
+  qLog(Debug) << watcher_ << "moved to thread" << watcher_thread_;
 
-  watcher_thread_->start(thread_priority_);
+  watcher_thread_->start(QThread::IdlePriority);
 
   watcher_->set_backend(backend_);
   watcher_->set_task_manager(app_->task_manager());
@@ -169,7 +163,9 @@ void SCollection::AbortScan() { watcher_->Stop(); }
 void SCollection::Rescan(const SongList &songs) {
 
   qLog(Debug) << "Rescan" << songs.size() << "songs";
-  if (!songs.isEmpty()) watcher_->RescanTracksAsync(songs);
+  if (!songs.isEmpty()) {
+    watcher_->RescanSongsAsync(songs);
+  }
 
 }
 
@@ -184,8 +180,6 @@ void SCollection::ReloadSettings() {
 
   QSettings s;
   s.beginGroup(CollectionSettingsPage::kSettingsGroup);
-  io_priority_ = static_cast<Utilities::IoPriority>(s.value("io_priority", Utilities::IOPRIO_CLASS_IDLE).toInt());
-  thread_priority_ = static_cast<QThread::Priority>(s.value("thread_priority", QThread::Priority::IdlePriority).toInt());
   save_playcounts_to_files_ = s.value("save_playcounts", false).toBool();
   save_ratings_to_files_ = s.value("save_ratings", false).toBool();
   s.endGroup();
@@ -219,9 +213,9 @@ void SCollection::SyncPlaycountAndRatingToFiles() {
 
 }
 
-void SCollection::SongsPlaycountChanged(const SongList &songs) {
+void SCollection::SongsPlaycountChanged(const SongList &songs, const bool save_tags) {
 
-  if (save_playcounts_to_files_) {
+  if (save_tags || save_playcounts_to_files_) {
     app_->tag_reader_client()->UpdateSongsPlaycount(songs);
   }
 
