@@ -2,7 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
- * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2018-2023, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ void CollectionBackend::Close() {
 }
 
 void CollectionBackend::ExitAsync() {
-  QMetaObject::invokeMethod(this, "Exit", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &CollectionBackend::Exit, Qt::QueuedConnection);
 }
 
 void CollectionBackend::Exit() {
@@ -105,31 +105,29 @@ void CollectionBackend::ReportErrors(const CollectionQuery &query) {
 
   const QSqlError sql_error = query.lastError();
   if (sql_error.isValid()) {
-    qLog(Error) << "Unable to execute collection SQL query: " << sql_error;
-    qLog(Error) << "Faulty SQL query: " << query.lastQuery();
-    qLog(Error) << "Bound SQL values: " << query.boundValues();
-    QString error;
-    error += "Unable to execute collection SQL query: " + sql_error.text() + "<br />";
-    error += "Faulty SQL query: " + query.lastQuery();
-    emit Error(error);
+    qLog(Error) << "Unable to execute collection SQL query:" << sql_error;
+    qLog(Error) << "Failed SQL query:" << query.lastQuery();
+    qLog(Error) << "Bound SQL values:" << query.boundValues();
+    emit Error(tr("Unable to execute collection SQL query: %1").arg(sql_error.text()));
+    emit Error(tr("Failed SQL query: %1").arg(query.lastQuery()));
   }
 
 }
 
 void CollectionBackend::LoadDirectoriesAsync() {
-  QMetaObject::invokeMethod(this, "LoadDirectories", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &CollectionBackend::LoadDirectories, Qt::QueuedConnection);
 }
 
 void CollectionBackend::UpdateTotalSongCountAsync() {
-  QMetaObject::invokeMethod(this, "UpdateTotalSongCount", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &CollectionBackend::UpdateTotalSongCount, Qt::QueuedConnection);
 }
 
 void CollectionBackend::UpdateTotalArtistCountAsync() {
-  QMetaObject::invokeMethod(this, "UpdateTotalArtistCount", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &CollectionBackend::UpdateTotalArtistCount, Qt::QueuedConnection);
 }
 
 void CollectionBackend::UpdateTotalAlbumCountAsync() {
-  QMetaObject::invokeMethod(this, "UpdateTotalAlbumCount", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &CollectionBackend::UpdateTotalAlbumCount, Qt::QueuedConnection);
 }
 
 void CollectionBackend::IncrementPlayCountAsync(const int id) {
@@ -1437,7 +1435,7 @@ CollectionBackend::AlbumList CollectionBackend::GetAlbums(const QString &artist,
   QSqlDatabase db(db_->Connect());
 
   CollectionQuery query(db, songs_table_, fts_table_, opt);
-  query.SetColumnSpec("url, effective_albumartist, album, compilation_effective, art_automatic, art_manual, filetype, cue_path");
+  query.SetColumnSpec("url, filetype, cue_path, effective_albumartist, album, compilation_effective, art_embedded, art_automatic, art_manual, art_unset");
   query.SetOrderBy("effective_albumartist, album, url");
 
   if (compilation_required) {
@@ -1455,42 +1453,48 @@ CollectionBackend::AlbumList CollectionBackend::GetAlbums(const QString &artist,
 
   QMap<QString, Album> albums;
   while (query.Next()) {
-    bool is_compilation = query.Value(3).toBool();
 
-    Album info;
+    Album album_info;
     QUrl url = QUrl::fromEncoded(query.Value(0).toByteArray());
+
+    album_info.filetype = static_cast<Song::FileType>(query.Value(1).toInt());
+    const QString filetype = Song::TextForFiletype(album_info.filetype);
+    album_info.cue_path = query.Value(2).toString();
+
+    const bool is_compilation = query.Value(5).toBool();
     if (!is_compilation) {
-      info.album_artist = query.Value(1).toString();
+      album_info.album_artist = query.Value(3).toString();
     }
-    info.album = query.Value(2).toString();
 
-    QString art_automatic = query.Value(4).toString();
+    album_info.album = query.Value(4).toString();
+
+    album_info.art_embedded = query.Value(6).toBool();
+
+    const QString art_automatic = query.Value(7).toString();
     if (art_automatic.contains(QRegularExpression("..+:.*"))) {
-      info.art_automatic = QUrl::fromEncoded(art_automatic.toUtf8());
+      album_info.art_automatic = QUrl::fromEncoded(art_automatic.toUtf8());
     }
     else {
-      info.art_automatic = QUrl::fromLocalFile(art_automatic);
+      album_info.art_automatic = QUrl::fromLocalFile(art_automatic);
     }
 
-    QString art_manual = query.Value(5).toString();
+    const QString art_manual = query.Value(8).toString();
     if (art_manual.contains(QRegularExpression("..+:.*"))) {
-      info.art_manual = QUrl::fromEncoded(art_manual.toUtf8());
+      album_info.art_manual = QUrl::fromEncoded(art_manual.toUtf8());
     }
     else {
-      info.art_manual = QUrl::fromLocalFile(art_manual);
+      album_info.art_manual = QUrl::fromLocalFile(art_manual);
     }
 
-    info.filetype = static_cast<Song::FileType>(query.Value(6).toInt());
-    QString filetype = Song::TextForFiletype(info.filetype);
-    info.cue_path = query.Value(7).toString();
+    album_info.art_unset = query.Value(9).toBool();
 
     QString key;
-    if (!info.album_artist.isEmpty()) {
-      key.append(info.album_artist);
+    if (!album_info.album_artist.isEmpty()) {
+      key.append(album_info.album_artist);
     }
-    if (!info.album.isEmpty()) {
+    if (!album_info.album.isEmpty()) {
       if (!key.isEmpty()) key.append("-");
-      key.append(info.album);
+      key.append(album_info.album);
     }
     if (!filetype.isEmpty()) {
       key.append(filetype);
@@ -1502,8 +1506,8 @@ CollectionBackend::AlbumList CollectionBackend::GetAlbums(const QString &artist,
       albums[key].urls.append(url);
     }
     else {
-      info.urls << url;
-      albums.insert(key, info);
+      album_info.urls << url;
+      albums.insert(key, album_info);
     }
 
   }
@@ -1522,7 +1526,7 @@ CollectionBackend::Album CollectionBackend::GetAlbumArt(const QString &effective
   ret.album_artist = effective_albumartist;
 
   CollectionQuery query(db, songs_table_, fts_table_);
-  query.SetColumnSpec("art_automatic, art_manual, url");
+  query.SetColumnSpec("url, art_embedded, art_automatic, art_manual, art_unset");
   if (!effective_albumartist.isEmpty()) {
     query.AddWhere("effective_albumartist", effective_albumartist);
   }
@@ -1534,22 +1538,24 @@ CollectionBackend::Album CollectionBackend::GetAlbumArt(const QString &effective
   }
 
   if (query.Next()) {
-    ret.art_automatic = QUrl::fromEncoded(query.Value(0).toByteArray());
-    ret.art_manual = QUrl::fromEncoded(query.Value(1).toByteArray());
-    ret.urls << QUrl::fromEncoded(query.Value(2).toByteArray());
+    ret.urls << QUrl::fromEncoded(query.Value(0).toByteArray());
+    ret.art_embedded = query.Value(1).toInt() == 1;
+    ret.art_automatic = QUrl::fromEncoded(query.Value(2).toByteArray());
+    ret.art_manual = QUrl::fromEncoded(query.Value(3).toByteArray());
+    ret.art_unset = query.Value(4).toInt() == 1;
   }
 
   return ret;
 
 }
 
-void CollectionBackend::UpdateManualAlbumArtAsync(const QString &effective_albumartist, const QString &album, const QUrl &cover_url, const bool clear_art_automatic) {
+void CollectionBackend::UpdateEmbeddedAlbumArtAsync(const QString &effective_albumartist, const QString &album, const bool art_embedded) {
 
-  QMetaObject::invokeMethod(this, "UpdateManualAlbumArt", Qt::QueuedConnection, Q_ARG(QString, effective_albumartist), Q_ARG(QString, album), Q_ARG(QUrl, cover_url), Q_ARG(bool, clear_art_automatic));
+  QMetaObject::invokeMethod(this, "UpdateEmbeddedAlbumArt", Qt::QueuedConnection, Q_ARG(QString, effective_albumartist), Q_ARG(QString, album), Q_ARG(bool, art_embedded));
 
 }
 
-void CollectionBackend::UpdateManualAlbumArt(const QString &effective_albumartist, const QString &album, const QUrl &cover_url, const bool clear_art_automatic) {
+void CollectionBackend::UpdateEmbeddedAlbumArt(const QString &effective_albumartist, const QString &album, const bool art_embedded) {
 
   QMutexLocker l(db_->Mutex());
   QSqlDatabase db(db_->Connect());
@@ -1573,15 +1579,11 @@ void CollectionBackend::UpdateManualAlbumArt(const QString &effective_albumartis
   }
 
   // Update the songs
-  QString sql = QString("UPDATE %1 SET art_manual = :cover").arg(songs_table_);
-  if (clear_art_automatic) {
-    sql += ", art_automatic = ''";
-  }
-  sql += " WHERE effective_albumartist = :effective_albumartist AND album = :album AND unavailable = 0";
+  QString sql = QString("UPDATE %1 SET art_embedded = :art_embedded, art_unset = 0 WHERE effective_albumartist = :effective_albumartist AND album = :album AND unavailable = 0").arg(songs_table_);
 
   SqlQuery q(db);
   q.prepare(sql);
-  q.BindValue(":cover", cover_url.isValid() ? cover_url.toString(QUrl::FullyEncoded) : "");
+  q.BindValue(":art_embedded", art_embedded ? 1 : 0);
   q.BindValue(":effective_albumartist", effective_albumartist);
   q.BindValue(":album", album);
 
@@ -1610,18 +1612,17 @@ void CollectionBackend::UpdateManualAlbumArt(const QString &effective_albumartis
 
 }
 
-void CollectionBackend::UpdateAutomaticAlbumArtAsync(const QString &effective_albumartist, const QString &album, const QUrl &cover_url, const bool clear_art_manual) {
+void CollectionBackend::UpdateManualAlbumArtAsync(const QString &effective_albumartist, const QString &album, const QUrl &art_manual) {
 
-  QMetaObject::invokeMethod(this, "UpdateAutomaticAlbumArt", Qt::QueuedConnection, Q_ARG(QString, effective_albumartist), Q_ARG(QString, album), Q_ARG(QUrl, cover_url), Q_ARG(bool, clear_art_manual));
+  QMetaObject::invokeMethod(this, "UpdateManualAlbumArt", Qt::QueuedConnection, Q_ARG(QString, effective_albumartist), Q_ARG(QString, album), Q_ARG(QUrl, art_manual));
 
 }
 
-void CollectionBackend::UpdateAutomaticAlbumArt(const QString &effective_albumartist, const QString &album, const QUrl &cover_url, const bool clear_art_manual) {
+void CollectionBackend::UpdateManualAlbumArt(const QString &effective_albumartist, const QString &album, const QUrl &art_manual) {
 
   QMutexLocker l(db_->Mutex());
   QSqlDatabase db(db_->Connect());
 
-  // Get the songs before they're updated
   CollectionQuery query(db, songs_table_, fts_table_);
   query.SetColumnSpec("ROWID, " + Song::kColumnSpec);
   query.AddWhere("effective_albumartist", effective_albumartist);
@@ -1639,16 +1640,124 @@ void CollectionBackend::UpdateAutomaticAlbumArt(const QString &effective_albumar
     deleted_songs << song;
   }
 
-  // Update the songs
-  QString sql = QString("UPDATE %1 SET art_automatic = :cover").arg(songs_table_);
-  if (clear_art_manual) {
-    sql += ", art_manual = ''";
-  }
-  sql += " WHERE effective_albumartist = :effective_albumartist AND album = :album AND unavailable = 0";
-
   SqlQuery q(db);
-  q.prepare(sql);
-  q.BindValue(":cover", cover_url.isValid() ? cover_url.toString(QUrl::FullyEncoded) : "");
+  q.prepare(QString("UPDATE %1 SET art_manual = :art_manual, art_unset = 0 WHERE effective_albumartist = :effective_albumartist AND album = :album AND unavailable = 0").arg(songs_table_));
+  q.BindValue(":art_manual", art_manual.isValid() ? art_manual.toString(QUrl::FullyEncoded) : "");
+  q.BindValue(":effective_albumartist", effective_albumartist);
+  q.BindValue(":album", album);
+
+  if (!q.Exec()) {
+    db_->ReportErrors(q);
+    return;
+  }
+
+  if (!query.Exec()) {
+    ReportErrors(query);
+    return;
+  }
+
+  SongList added_songs;
+  while (query.Next()) {
+    Song song(source_);
+    song.InitFromQuery(query, true);
+    added_songs << song;
+  }
+
+  if (!added_songs.isEmpty() || !deleted_songs.isEmpty()) {
+    emit SongsDeleted(deleted_songs);
+    emit SongsDiscovered(added_songs);
+  }
+
+}
+
+void CollectionBackend::UnsetAlbumArtAsync(const QString &effective_albumartist, const QString &album) {
+
+  QMetaObject::invokeMethod(this, "UnsetAlbumArt", Qt::QueuedConnection, Q_ARG(QString, effective_albumartist), Q_ARG(QString, album));
+
+}
+
+void CollectionBackend::UnsetAlbumArt(const QString &effective_albumartist, const QString &album) {
+
+  QMutexLocker l(db_->Mutex());
+  QSqlDatabase db(db_->Connect());
+
+  CollectionQuery query(db, songs_table_, fts_table_);
+  query.SetColumnSpec("ROWID, " + Song::kColumnSpec);
+  query.AddWhere("effective_albumartist", effective_albumartist);
+  query.AddWhere("album", album);
+
+  if (!query.Exec()) {
+    ReportErrors(query);
+    return;
+  }
+
+  SongList deleted_songs;
+  while (query.Next()) {
+    Song song(source_);
+    song.InitFromQuery(query, true);
+    deleted_songs << song;
+  }
+
+  SqlQuery q(db);
+  q.prepare(QString("UPDATE %1 SET art_unset = 1, art_manual = '', art_automatic = '', art_embedded = '' WHERE effective_albumartist = :effective_albumartist AND album = :album AND unavailable = 0").arg(songs_table_));
+  q.BindValue(":effective_albumartist", effective_albumartist);
+  q.BindValue(":album", album);
+
+  if (!q.Exec()) {
+    db_->ReportErrors(q);
+    return;
+  }
+
+  if (!query.Exec()) {
+    ReportErrors(query);
+    return;
+  }
+
+  SongList added_songs;
+  while (query.Next()) {
+    Song song(source_);
+    song.InitFromQuery(query, true);
+    added_songs << song;
+  }
+
+  if (!added_songs.isEmpty() || !deleted_songs.isEmpty()) {
+    emit SongsDeleted(deleted_songs);
+    emit SongsDiscovered(added_songs);
+  }
+
+}
+
+void CollectionBackend::ClearAlbumArtAsync(const QString &effective_albumartist, const QString &album, const bool unset) {
+
+  QMetaObject::invokeMethod(this, "ClearAlbumArt", Qt::QueuedConnection, Q_ARG(QString, effective_albumartist), Q_ARG(QString, album), Q_ARG(bool, unset));
+
+}
+
+void CollectionBackend::ClearAlbumArt(const QString &effective_albumartist, const QString &album, const bool art_unset) {
+
+  QMutexLocker l(db_->Mutex());
+  QSqlDatabase db(db_->Connect());
+
+  CollectionQuery query(db, songs_table_, fts_table_);
+  query.SetColumnSpec("ROWID, " + Song::kColumnSpec);
+  query.AddWhere("effective_albumartist", effective_albumartist);
+  query.AddWhere("album", album);
+
+  if (!query.Exec()) {
+    ReportErrors(query);
+    return;
+  }
+
+  SongList deleted_songs;
+  while (query.Next()) {
+    Song song(source_);
+    song.InitFromQuery(query, true);
+    deleted_songs << song;
+  }
+
+  SqlQuery q(db);
+  q.prepare(QString("UPDATE %1 SET art_embedded = 0, art_automatic = '', art_manual = '', art_unset = :art_unset WHERE effective_albumartist = :effective_albumartist AND album = :album AND unavailable = 0").arg(songs_table_));
+  q.BindValue(":art_unset", art_unset ? 1 : 0);
   q.BindValue(":effective_albumartist", effective_albumartist);
   q.BindValue(":album", album);
 
@@ -1657,7 +1766,6 @@ void CollectionBackend::UpdateAutomaticAlbumArt(const QString &effective_albumar
     return;
   }
 
-  // Now get the updated songs
   if (!query.Exec()) {
     ReportErrors(query);
     return;
@@ -1827,7 +1935,7 @@ bool CollectionBackend::ResetPlayStatistics(const QStringList &id_str_list) {
 
 void CollectionBackend::DeleteAllAsync() {
 
-  QMetaObject::invokeMethod(this, "DeleteAll", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &CollectionBackend::DeleteAll, Qt::QueuedConnection);
 
 }
 
