@@ -38,7 +38,7 @@
 #include <qdbusextratypes.h>
 #include <QJsonObject>
 
-#include "engine/engine_fwd.h"
+#include "engine/enginebase.h"
 #include "covermanager/albumcoverloaderresult.h"
 
 class Application;
@@ -188,22 +188,22 @@ class Mpris2 : public QObject {
 
  signals:
   // Player
-  void Seeked(qint64 position);
+  void Seeked(const qint64 position);
 
   // TrackList
-  void TrackListReplaced(Track_Ids Tracks, QDBusObjectPath CurrentTrack);
-  void TrackAdded(TrackMetadata Metadata, QDBusObjectPath AfterTrack);
-  void TrackRemoved(QDBusObjectPath trackId);
-  void TrackMetadataChanged(QDBusObjectPath trackId, TrackMetadata metadata);
+  void TrackListReplaced(const Track_Ids &tracks, const QDBusObjectPath &current_track);
+  void TrackAdded(const TrackMetadata &metadata, const QDBusObjectPath &after_track);
+  void TrackRemoved(const QDBusObjectPath &track_id);
+  void TrackMetadataChanged(const QDBusObjectPath &track_id, const TrackMetadata &metadata);
 
   void RaiseMainWindow();
 
   // Playlist
-  void PlaylistChanged(MprisPlaylist playlist);
+  void PlaylistChanged(const MprisPlaylist &playlist);
 
  private slots:
   void AlbumCoverLoaded(const Song &song, const AlbumCoverLoaderResult &result = AlbumCoverLoaderResult());
-  void EngineStateChanged(Engine::State newState);
+  void EngineStateChanged(EngineBase::State newState);
   void VolumeChanged();
 
   void PlaylistManagerInitialized();
@@ -218,11 +218,11 @@ class Mpris2 : public QObject {
   void EmitNotification(const QString &name, const QVariant &value);
   void EmitNotification(const QString &name, const QVariant &value, const QString &mprisEntity);
 
-  QString PlaybackStatus(Engine::State state) const;
+  QString PlaybackStatus(EngineBase::State state) const;
 
   QString current_track_id() const;
 
-  bool CanSeek(Engine::State state) const;
+  bool CanSeek(EngineBase::State state) const;
 
   QString DesktopEntryAbsolutePath() const;
 
