@@ -35,7 +35,7 @@
 #include "core/scopedtransaction.h"
 #include "devicedatabasebackend.h"
 
-const int DeviceDatabaseBackend::kDeviceSchemaVersion = 3;
+const int DeviceDatabaseBackend::kDeviceSchemaVersion = 4;
 
 DeviceDatabaseBackend::DeviceDatabaseBackend(QObject *parent)
     : QObject(parent),
@@ -58,7 +58,7 @@ void DeviceDatabaseBackend::Close() {
 }
 
 void DeviceDatabaseBackend::ExitAsync() {
-  QMetaObject::invokeMethod(this, "Exit", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &DeviceDatabaseBackend::Exit, Qt::QueuedConnection);
 }
 
 void DeviceDatabaseBackend::Exit() {
