@@ -44,12 +44,10 @@
 #include <QString>
 #include <QUrl>
 
+#include "enginemetadata.h"
+
 class QTimerEvent;
 class GstBufferConsumer;
-
-namespace Engine {
-struct SimpleMetaBundle;
-}  // namespace Engine
 struct GstPlayBin;
 
 class GstEnginePipeline : public QObject {
@@ -78,7 +76,7 @@ class GstEnginePipeline : public QObject {
   void set_fading_enabled(const bool enabled);
 
   // Creates the pipeline, returns false on error
-  bool InitFromUrl(const QByteArray &stream_url, const QUrl &original_url, const qint64 end_nanosec, QString &error);
+  bool InitFromUrl(const QUrl &media_url, const QUrl &stream_url, const QByteArray &gst_url, const qint64 end_nanosec, QString &error);
 
   // GstBufferConsumers get fed audio data.  Thread-safe.
   void AddBufferConsumer(GstBufferConsumer *consumer);
@@ -95,16 +93,19 @@ class GstEnginePipeline : public QObject {
   void StartFader(const qint64 duration_nanosec, const QTimeLine::Direction direction = QTimeLine::Forward, const QEasingCurve::Type shape = QEasingCurve::Linear, const bool use_fudge_timer = true);
 
   // If this is set then it will be loaded automatically when playback finishes for gapless playback
-  void SetNextUrl(const QByteArray &stream_url, const QUrl &original_url, qint64 beginning_nanosec, qint64 end_nanosec);
-  bool has_next_valid_url() const { return !next_stream_url_.isEmpty(); }
+  void PrepareNextUrl(const QUrl &media_url, const QUrl &stream_url, const QByteArray &gst_url, const qint64 beginning_nanosec, const qint64 end_nanosec);
+  void SetNextUrl();
+  bool has_next_valid_url() const { return next_stream_url_.isValid(); }
 
   void SetSourceDevice(const QString &device) { source_device_ = device; }
 
   // Get information about the music playback
-  QByteArray stream_url() const { return stream_url_; }
-  QByteArray next_stream_url() const { return next_stream_url_; }
-  QUrl original_url() const { return original_url_; }
-  QUrl next_original_url() const { return next_original_url_; }
+  QUrl media_url() const { return media_url_; }
+  QUrl stream_url() const { return stream_url_; }
+  QByteArray gst_url() const { return gst_url_; }
+  QUrl next_media_url() const { return next_media_url_; }
+  QUrl next_stream_url() const { return next_stream_url_; }
+  QByteArray next_gst_url() const { return next_gst_url_; }
   bool is_valid() const { return valid_; }
 
   // Please note that this method (unlike GstEngine's.position()) is multiple-section media unaware.
@@ -126,18 +127,20 @@ class GstEnginePipeline : public QObject {
   void SetFaderVolume(const qreal volume);
 
  signals:
-  void Error(int pipeline_id, int domain, int error_code, QString message, QString debug);
+  void Error(const int pipeline_id, const int domain, const int error_code, const QString &message, const QString &debug);
 
-  void EndOfStreamReached(int pipeline_id, bool has_next_track);
-  void MetadataFound(int pipeline_id, const Engine::SimpleMetaBundle &bundle);
+  void EndOfStreamReached(const int pipeline_id, const bool has_next_track);
+  void MetadataFound(const int pipeline_id, const EngineMetadata &bundle);
 
-  void VolumeChanged(uint volume);
+  void VolumeChanged(const uint volume);
   void FaderFinished();
 
   void BufferingStarted();
-  void BufferingProgress(int percent);
+  void BufferingProgress(const int percent);
   void BufferingFinished();
 
+  void AboutToFinish();
+
  protected:
   void timerEvent(QTimerEvent*) override;
 
@@ -239,10 +242,12 @@ class GstEnginePipeline : public QObject {
   bool segment_start_received_;
 
   // The URL that is currently playing, and the URL that is to be preloaded when the current track is close to finishing.
-  QByteArray stream_url_;
-  QUrl original_url_;
-  QByteArray next_stream_url_;
-  QUrl next_original_url_;
+  QUrl media_url_;
+  QUrl stream_url_;
+  QByteArray gst_url_;
+  QUrl next_media_url_;
+  QUrl next_stream_url_;
+  QByteArray next_gst_url_;
 
   // If this is > 0 then the pipeline will be forced to stop when playback goes past this position.
   qint64 end_offset_nanosec_;
@@ -277,6 +282,7 @@ class GstEnginePipeline : public QObject {
   // Complete the transition to the next song when it starts playing
   bool next_uri_set_;
 
+  bool volume_set_;
   gdouble volume_internal_;
   uint volume_percent_;
 
@@ -312,6 +318,8 @@ class GstEnginePipeline : public QObject {
 
   bool logged_unsupported_analyzer_format_;
 
+  bool about_to_finish_;
+
 };
 
 #endif  // GSTENGINEPIPELINE_H
