@@ -109,7 +109,7 @@ void InternetCollectionView::SaveFocus() {
 
   QModelIndex current = currentIndex();
   QVariant type = model()->data(current, CollectionModel::Role_Type);
-  if (!type.isValid() || !(type.toInt() == CollectionItem::Type_Song || type.toInt() == CollectionItem::Type_Container || type.toInt() == CollectionItem::Type_Divider)) {
+  if (!type.isValid() || (type.toInt() != CollectionItem::Type_Song && type.toInt() != CollectionItem::Type_Container && type.toInt() != CollectionItem::Type_Divider)) {
     return;
   }
 
@@ -146,7 +146,7 @@ void InternetCollectionView::SaveContainerPath(const QModelIndex &child) {
 
   QModelIndex current = model()->parent(child);
   QVariant type = model()->data(current, CollectionModel::Role_Type);
-  if (!type.isValid() || !(type.toInt() == CollectionItem::Type_Container || type.toInt() == CollectionItem::Type_Divider)) {
+  if (!type.isValid() || (type.toInt() != CollectionItem::Type_Container && type.toInt() != CollectionItem::Type_Divider)) {
     return;
   }
 
