@@ -50,9 +50,9 @@ const char *AcoustidClient::kClientId = "0qjUoxbowg";
 const char *AcoustidClient::kUrl = "https://api.acoustid.org/v2/lookup";
 const int AcoustidClient::kDefaultTimeout = 5000;  // msec
 
-AcoustidClient::AcoustidClient(QObject *parent)
+AcoustidClient::AcoustidClient(NetworkAccessManager *network, QObject *parent)
     : QObject(parent),
-      network_(new NetworkAccessManager(this)),
+      network_(network),
       timeouts_(new NetworkTimeouts(kDefaultTimeout, this)) {}
 
 AcoustidClient::~AcoustidClient() {
