@@ -43,7 +43,7 @@ class AcoustidClient : public QObject {
   // IDs are provided by the caller when a request is started and included in the Finished signal - they have no meaning to AcoustidClient.
 
  public:
-  explicit AcoustidClient(QObject *parent = nullptr);
+  explicit AcoustidClient(NetworkAccessManager *network, QObject *parent = nullptr);
   ~AcoustidClient() override;
 
   // Network requests will be aborted after this interval.
@@ -59,7 +59,7 @@ class AcoustidClient : public QObject {
   void CancelAll();
 
  signals:
-  void Finished(int id, QStringList mbid_list, QString error = QString());
+  void Finished(const int id, const QStringList &mbid_list, const QString &error = QString());
 
  private slots:
   void RequestFinished(QNetworkReply *reply, const int id);
