@@ -74,9 +74,9 @@ class Organize : public QObject {
   void Start();
 
  signals:
-  void Finished(QStringList files_with_errors, QStringList);
-  void FileCopied(int database_id);
-  void SongPathChanged(Song song, QFileInfo new_file, std::optional<int> new_collection_directory_id);
+  void Finished(const QStringList &files_with_errors, const QStringList&);
+  void FileCopied(const int database_id);
+  void SongPathChanged(const Song &song, const QFileInfo &new_file, const std::optional<int> new_collection_directory_id);
 
  protected:
   void timerEvent(QTimerEvent *e) override;
