@@ -117,25 +117,25 @@ class PlaylistManagerInterface : public QObject {
   void PlaylistManagerInitialized();
   void AllPlaylistsLoaded();
 
-  void PlaylistAdded(int id, QString name, bool favorite);
-  void PlaylistDeleted(int id);
-  void PlaylistClosed(int id);
-  void PlaylistRenamed(int id, QString new_name);
-  void PlaylistFavorited(int id, bool favorite);
-  void CurrentChanged(Playlist *new_playlist, int scroll_position = 0);
+  void PlaylistAdded(const int id, const QString &name, const bool favorite);
+  void PlaylistDeleted(const int id);
+  void PlaylistClosed(const int id);
+  void PlaylistRenamed(const int id, const QString &new_name);
+  void PlaylistFavorited(const int id, const bool favorite);
+  void CurrentChanged(Playlist *new_playlist, const int scroll_position = 0);
   void ActiveChanged(Playlist *new_playlist);
 
-  void Error(QString message);
-  void SummaryTextChanged(QString summary);
+  void Error(const QString &message);
+  void SummaryTextChanged(const QString &summary);
 
   // Forwarded from individual playlists
-  void CurrentSongChanged(Song song);
-  void SongMetadataChanged(Song song);
+  void CurrentSongChanged(const Song &song);
+  void SongMetadataChanged(const Song &song);
 
   // Signals that one of manager's playlists has changed (new items, new ordering etc.) - the argument shows which.
   void PlaylistChanged(Playlist *playlist);
-  void EditingFinished(int playlist_id, QModelIndex idx);
-  void PlayRequested(QModelIndex idx, Playlist::AutoScroll autoscroll);
+  void EditingFinished(const int playlist_id, const QModelIndex idx);
+  void PlayRequested(const QModelIndex idx, const Playlist::AutoScroll autoscroll);
 };
 
 class PlaylistManager : public PlaylistManagerInterface {
