@@ -99,11 +99,11 @@ class QobuzRequest : public QobuzBaseRequest {
 
  signals:
   void LoginSuccess();
-  void LoginFailure(QString failure_reason);
-  void Results(int id, SongMap songs, QString error);
-  void UpdateStatus(int id, QString text);
-  void UpdateProgress(int id, int max);
-  void StreamURLFinished(QUrl original_url, QUrl url, Song::FileType, QString error = QString());
+  void LoginFailure(const QString &failure_reason);
+  void Results(const int id, const SongMap &songs, const QString &error);
+  void UpdateStatus(const int id, const QString &text);
+  void UpdateProgress(const int id, const int max);
+  void StreamURLFinished(const QUrl &media_url, const QUrl &url, const Song::FileType filetype, const QString &error = QString());
 
  private slots:
   void ArtistsReplyReceived(QNetworkReply *reply, const int limit_requested, const int offset_requested);
