@@ -83,9 +83,9 @@ class Queue : public QAbstractProxyModel {
   void UpdateSummaryText();
 
  signals:
-  void TotalLengthChanged(quint64 length);
-  void ItemCountChanged(int count);
-  void SummaryTextChanged(QString message);
+  void TotalLengthChanged(const quint64 length);
+  void ItemCountChanged(const int count);
+  void SummaryTextChanged(const QString &message);
 
  private slots:
   void SourceDataChanged(const QModelIndex &top_left, const QModelIndex &bottom_right);
