@@ -44,7 +44,7 @@ void RadioBackend::Close() {
 }
 
 void RadioBackend::ExitAsync() {
-  QMetaObject::invokeMethod(this, "Exit", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &RadioBackend::Exit, Qt::QueuedConnection);
 }
 
 void RadioBackend::Exit() {
@@ -85,7 +85,7 @@ void RadioBackend::AddChannels(const RadioChannelList &channels) {
 
 void RadioBackend::GetChannelsAsync() {
 
-  QMetaObject::invokeMethod(this, "GetChannels", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &RadioBackend::GetChannels, Qt::QueuedConnection);
 
 }
 
@@ -117,7 +117,7 @@ void RadioBackend::GetChannels() {
 }
 
 void RadioBackend::DeleteChannelsAsync() {
-  QMetaObject::invokeMethod(this, "DeleteChannels", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, &RadioBackend::DeleteChannels, Qt::QueuedConnection);
 }
 
 void RadioBackend::DeleteChannels() {
