@@ -37,7 +37,7 @@
 
 class QNetworkReply;
 
-class Application;
+class AudioScrobbler;
 class NetworkAccessManager;
 class LocalRedirectServer;
 
@@ -45,7 +45,7 @@ class ScrobblingAPI20 : public ScrobblerService {
   Q_OBJECT
 
  public:
-  explicit ScrobblingAPI20(const QString &name, const QString &settings_group, const QString &auth_url, const QString &api_url, const bool batch, const QString &cache_file, Application *app, QObject *parent = nullptr);
+  explicit ScrobblingAPI20(const QString &name, const QString &settings_group, const QString &auth_url, const QString &api_url, const bool batch, const QString &cache_file, AudioScrobbler *scrobbler, NetworkAccessManager *network, QObject *parent = nullptr);
   ~ScrobblingAPI20() override;
 
   static const char *kApiKey;
@@ -70,7 +70,7 @@ class ScrobblingAPI20 : public ScrobblerService {
   void Love() override;
 
  signals:
-  void AuthenticationComplete(bool success, QString error = QString());
+  void AuthenticationComplete(const bool success, const QString &error = QString());
 
  public slots:
   void WriteCache() override { cache_->WriteCache(); }
@@ -79,11 +79,16 @@ class ScrobblingAPI20 : public ScrobblerService {
   void RedirectArrived();
   void AuthenticateReplyFinished(QNetworkReply *reply);
   void UpdateNowPlayingRequestFinished(QNetworkReply *reply);
-  void ScrobbleRequestFinished(QNetworkReply *reply, const QList<quint64> &list);
-  void SingleScrobbleRequestFinished(QNetworkReply *reply, const quint64 timestamp);
+  void ScrobbleRequestFinished(QNetworkReply *reply, ScrobblerCacheItemPtrList cache_items);
+  void SingleScrobbleRequestFinished(QNetworkReply *reply, ScrobblerCacheItemPtr cache_item);
   void LoveRequestFinished(QNetworkReply *reply);
 
  private:
+  enum class ReplyResult {
+    Success,
+    ServerError,
+    APIError
+  };
 
   enum class ScrobbleErrorCode {
     NoError = 1,
@@ -120,12 +125,12 @@ class ScrobblingAPI20 : public ScrobblerService {
   static const int kScrobblesPerRequest;
 
   QNetworkReply *CreateRequest(const ParamList &request_params);
-  QByteArray GetReplyData(QNetworkReply *reply);
+  ReplyResult GetJsonObject(QNetworkReply *reply, QJsonObject &json_obj, QString &error_description);
 
   void RequestSession(const QString &token);
   void AuthError(const QString &error);
   void SendSingleScrobble(ScrobblerCacheItemPtr item);
-  void Error(const QString &error, const QVariant &debug = QVariant()) override;
+  void Error(const QString &error, const QVariant &debug = QVariant());
   static QString ErrorString(const ScrobbleErrorCode error);
   void StartSubmit(const bool initial = false) override;
   void CheckScrobblePrevSong();
@@ -137,7 +142,7 @@ class ScrobblingAPI20 : public ScrobblerService {
   QString api_url_;
   bool batch_;
 
-  Application *app_;
+  AudioScrobbler *scrobbler_;
   NetworkAccessManager *network_;
   ScrobblerCache *cache_;
   LocalRedirectServer *server_;
