@@ -80,8 +80,8 @@ class SmartPlaylistQueryWizardPlugin::SortPage : public QWizardPage {  // clazy:
   SmartPlaylistQueryWizardPlugin *plugin_;
 };
 
-SmartPlaylistQueryWizardPlugin::SmartPlaylistQueryWizardPlugin(Application *app, CollectionBackend *collection, QObject *parent)
-    : SmartPlaylistWizardPlugin(app, collection, parent),
+SmartPlaylistQueryWizardPlugin::SmartPlaylistQueryWizardPlugin(Application *app, CollectionBackend *collection_backend, QObject *parent)
+    : SmartPlaylistWizardPlugin(app, collection_backend, parent),
       search_page_(nullptr),
       previous_scrollarea_max_(0) {}
 
@@ -107,7 +107,7 @@ int SmartPlaylistQueryWizardPlugin::CreatePages(QWizard *wizard, int finish_page
   QObject::connect(search_page_->ui_->type, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SmartPlaylistQueryWizardPlugin::SearchTypeChanged);
 
   // Create the new search term widget
-  search_page_->new_term_ = new SmartPlaylistSearchTermWidget(collection_, search_page_);
+  search_page_->new_term_ = new SmartPlaylistSearchTermWidget(collection_backend_, search_page_);
   search_page_->new_term_->SetActive(false);
   QObject::connect(search_page_->new_term_, &SmartPlaylistSearchTermWidget::Clicked, this, &SmartPlaylistQueryWizardPlugin::AddSearchTerm);
 
@@ -124,11 +124,11 @@ int SmartPlaylistQueryWizardPlugin::CreatePages(QWizard *wizard, int finish_page
   terms_page_layout->addStretch();
   search_page_->preview_ = new SmartPlaylistSearchPreview(search_page_);
   search_page_->preview_->set_application(app_);
-  search_page_->preview_->set_collection(collection_);
+  search_page_->preview_->set_collection(collection_backend_);
   terms_page_layout->addWidget(search_page_->preview_);
 
   // Add sort field texts
-  for (int i = 0; i < SmartPlaylistSearchTerm::FieldCount; ++i) {
+  for (int i = 0; i < static_cast<int>(SmartPlaylistSearchTerm::Field::FieldCount); ++i) {
     const SmartPlaylistSearchTerm::Field field = static_cast<SmartPlaylistSearchTerm::Field>(i);
     const QString field_name = SmartPlaylistSearchTerm::FieldName(field);
     sort_ui_->field_value->addItem(field_name);
@@ -143,7 +143,7 @@ int SmartPlaylistQueryWizardPlugin::CreatePages(QWizard *wizard, int finish_page
 
   // Set up the preview widget that's already at the bottom of the sort page
   sort_ui_->preview->set_application(app_);
-  sort_ui_->preview->set_collection(collection_);
+  sort_ui_->preview->set_collection(collection_backend_);
   QObject::connect(sort_ui_->field, &QRadioButton::toggled, this, &SmartPlaylistQueryWizardPlugin::UpdateSortPreview);
   QObject::connect(sort_ui_->field_value, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SmartPlaylistQueryWizardPlugin::UpdateSortPreview);
   QObject::connect(sort_ui_->limit_limit, &QRadioButton::toggled, this, &SmartPlaylistQueryWizardPlugin::UpdateSortPreview);
@@ -172,7 +172,7 @@ void SmartPlaylistQueryWizardPlugin::SetGenerator(PlaylistGeneratorPtr g) {
   SmartPlaylistSearch search = gen->search();
 
   // Search type
-  search_page_->ui_->type->setCurrentIndex(search.search_type_);
+  search_page_->ui_->type->setCurrentIndex(static_cast<int>(search.search_type_));
 
   // Search terms
   qDeleteAll(search_page_->terms_);
@@ -184,13 +184,13 @@ void SmartPlaylistQueryWizardPlugin::SetGenerator(PlaylistGeneratorPtr g) {
   }
 
   // Sort order
-  if (search.sort_type_ == SmartPlaylistSearch::Sort_Random) {
+  if (search.sort_type_ == SmartPlaylistSearch::SortType::Random) {
     sort_ui_->random->setChecked(true);
   }
   else {
     sort_ui_->field->setChecked(true);
-    sort_ui_->order->setCurrentIndex(search.sort_type_ == SmartPlaylistSearch::Sort_FieldAsc ? 0 : 1);
-    sort_ui_->field_value->setCurrentIndex(search.sort_field_);
+    sort_ui_->order->setCurrentIndex(search.sort_type_ == SmartPlaylistSearch::SortType::FieldAsc ? 0 : 1);
+    sort_ui_->field_value->setCurrentIndex(static_cast<int>(search.sort_field_));
   }
 
   // Limit
@@ -230,7 +230,7 @@ void SmartPlaylistQueryWizardPlugin::UpdateSortOrder() {
 
 void SmartPlaylistQueryWizardPlugin::AddSearchTerm() {
 
-  SmartPlaylistSearchTermWidget *widget = new SmartPlaylistSearchTermWidget(collection_, search_page_);
+  SmartPlaylistSearchTermWidget *widget = new SmartPlaylistSearchTermWidget(collection_backend_, search_page_);
   QObject::connect(widget, &SmartPlaylistSearchTermWidget::RemoveClicked, this, &SmartPlaylistQueryWizardPlugin::RemoveSearchTerm);
   QObject::connect(widget, &SmartPlaylistSearchTermWidget::Changed, this, &SmartPlaylistQueryWizardPlugin::UpdateTermPreview);
 
@@ -292,11 +292,11 @@ SmartPlaylistSearch SmartPlaylistQueryWizardPlugin::MakeSearch() const {
 
   // Sort order
   if (sort_ui_->random->isChecked()) {
-    ret.sort_type_ = SmartPlaylistSearch::Sort_Random;
+    ret.sort_type_ = SmartPlaylistSearch::SortType::Random;
   }
   else {
     const bool ascending = sort_ui_->order->currentIndex() == 0;
-    ret.sort_type_ = ascending ? SmartPlaylistSearch::Sort_FieldAsc : SmartPlaylistSearch::Sort_FieldDesc;
+    ret.sort_type_ = ascending ? SmartPlaylistSearch::SortType::FieldAsc : SmartPlaylistSearch::SortType::FieldDesc;
     ret.sort_field_ = static_cast<SmartPlaylistSearchTerm::Field>(sort_ui_->field_value->currentIndex());
   }
 
