@@ -87,7 +87,7 @@ using namespace std::chrono_literals;
 TidalService::TidalService(Application *app, QObject *parent)
     : InternetService(Song::Source::Tidal, "Tidal", "tidal", TidalSettingsPage::kSettingsGroup, SettingsDialog::Page::Tidal, app, parent),
       app_(app),
-      network_(new NetworkAccessManager(this)),
+      network_(app->network()),
       url_handler_(new TidalUrlHandler(app, this)),
       artists_collection_backend_(nullptr),
       albums_collection_backend_(nullptr),
@@ -1003,21 +1003,21 @@ uint TidalService::GetStreamURL(const QUrl &url, QString &error) {
 
 }
 
-void TidalService::HandleStreamURLFailure(const uint id, const QUrl &original_url, const QString &error) {
+void TidalService::HandleStreamURLFailure(const uint id, const QUrl &media_url, const QString &error) {
 
   if (!stream_url_requests_.contains(id)) return;
   stream_url_requests_.remove(id);
 
-  emit StreamURLFailure(id, original_url, error);
+  emit StreamURLFailure(id, media_url, error);
 
 }
 
-void TidalService::HandleStreamURLSuccess(const uint id, const QUrl &original_url, const QUrl &stream_url, const Song::FileType filetype, const int samplerate, const int bit_depth, const qint64 duration) {
+void TidalService::HandleStreamURLSuccess(const uint id, const QUrl &media_url, const QUrl &stream_url, const Song::FileType filetype, const int samplerate, const int bit_depth, const qint64 duration) {
 
   if (!stream_url_requests_.contains(id)) return;
   stream_url_requests_.remove(id);
 
-  emit StreamURLSuccess(id, original_url, stream_url, filetype, samplerate, bit_depth, duration);
+  emit StreamURLSuccess(id, media_url, stream_url, filetype, samplerate, bit_depth, duration);
 
 }
 
