@@ -60,7 +60,7 @@ FileView::FileView(QWidget *parent)
       model_(nullptr),
       undo_stack_(new QUndoStack(this)),
       task_manager_(nullptr),
-      storage_(new FilesystemMusicStorage(Song::Source_LocalFile, "/")) {
+      storage_(new FilesystemMusicStorage(Song::Source::LocalFile, "/")) {
 
   ui_->setupUi(this);
 
@@ -255,7 +255,7 @@ void FileView::DeleteFinished(const SongList &songs_with_errors) {
   if (songs_with_errors.isEmpty()) return;
 
   OrganizeErrorDialog *dialog = new OrganizeErrorDialog(this);
-  dialog->Show(OrganizeErrorDialog::Type_Delete, songs_with_errors);
+  dialog->Show(OrganizeErrorDialog::OperationType::Delete, songs_with_errors);
   // It deletes itself when the user closes it
 
 }
