@@ -49,11 +49,7 @@ MultiLoadingIndicator::MultiLoadingIndicator(QWidget *parent)
 
 QSize MultiLoadingIndicator::sizeHint() const {
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
   const int width = kHorizontalPadding * 2 + spinner_->sizeHint().width() + kSpacing + fontMetrics().horizontalAdvance(text_);
-#else
-  const int width = kHorizontalPadding * 2 + spinner_->sizeHint().width() + kSpacing + fontMetrics().width(text_);
-#endif
   const int height = kVerticalPadding * 2 + qMax(spinner_->sizeHint().height(), fontMetrics().height());
 
   return QSize(width, height);
