@@ -36,7 +36,7 @@ class QSearchField : public QWidget {
   void setFocus();
 
  signals:
-  void textChanged(QString text);
+  void textChanged(const QString &text);
   void editingFinished();
   void returnPressed();
 
